@@ -11,9 +11,9 @@ using namespace vivid;
 // neighbours...
 
 vector<double> GetParticlesVolume(const CVoronoiVolume &arSurf);
-vector<double> GetParticlesDensity(const CVoronoiVolume &arSurf, const std::vector<double> &arMassField);
-vector<double> GetSurfaceAreas(const CVoronoiVolume &arSurf);
-vector<double> CalculateFlux(const CVoronoiVolume &arSurf, const CPoint &arField);
+vector<coord_t> GetParticlesDensity(const CVoronoiVolume &arSurf, const std::vector<double> &arMassField);
+vector<coord_t> GetSurfaceAreas(const CVoronoiVolume &arSurf);
+vector<coord_t> CalculateFlux(const CVoronoiVolume &arSurf, const CPoint &arField);
 
 //} // namespace vivid
 #endif //VIVID_ANALYSIS_H
