@@ -4,247 +4,34 @@
 namespace vivid {
     namespace {
         constexpr float MAX_ROUGHNESS = 1000;
-    }
-
-    namespace AssimpExport {
         // matches assimp file formats to actual file endings
-        std::map<std::string, std::string> fileFormats =
+        const std::map<std::string, std::string> FILE_FORMATS =
             {
-                {"glb",     ".glb"},    // Doesn't work well
-                {"glb2",    ".glb"},    // Works
-                {"gltf",    ".gltf"},   // Works
-                {"gltf2",   ".gltf"},   // Works
-                {"obj",     ".obj"},    // Works
-                {"fbx",     ".fbx"},    // Doesn't work well
-                {"ply",     ".ply"},    // Untested
-                {"3ds",     ".3ds"},    // Untested
-                {"stl",     ".stl"},    // Untested
-                {"stlb",    ".stl"},    // Untested
-                {"collada", ".dae"}     // Untested
+                    {"glb",     ".glb"},    // Works
+                    {"gltf",    ".gltf"},   // Works
+                    {"obj",     ".obj"},    // Works
+                    {"fbx",     ".fbx"},    // Doesn't work well
+                    {"ply",     ".ply"},    // Untested
+                    {"3ds",     ".3ds"},    // Untested
+                    {"stl",     ".stl"},    // Untested
+                    {"stlb",    ".stl"},    // Untested
+                    {"collada", ".dae"}     // Untested
             };
 
+        std::string RenameGLTF_GLB(const std::string& arFileFormat) {
+            if (arFileFormat == "glb" || arFileFormat == "gltf") {
+                return arFileFormat + "2";
+            }
+            return arFileFormat;
+        }
+
+
         map<string, string> TextureNameToIndex = {};
         vector<aiTexture*> EmbeddedTextures = {};
         bool EmbeddedTexture = false;
         string OutputPath = "";
 
-        CBlobData AssimpExporter(vivid::CModel &arModel, const std::string &arFileType) { //blob
-            Assimp::Exporter exp;
-            EmbeddedTexture = true;
-
-            aiScene *scene = GenerateScene(arModel);
-            auto blob = exp.ExportToBlob(scene, arFileType,
-                                   aiProcess_JoinIdenticalVertices | aiProcess_FixInfacingNormals | aiProcess_GenSmoothNormals);
-
-            EmbeddedTextures.clear();
-            EmbeddedTexture = false;
-            TextureNameToIndex.clear();
-            delete scene;
-            
-            if (!blob) {
-                Log(LOG_ERROR, exp.GetErrorString());
-            }
-            // we copy all the blob data to a vivid const qualified struct so the blob pointer isn't freed by python's greedy GC
-            return CBlobData::FormatExportDataBlob(blob);
-        }
-
-        CBlobData AnimationExporter(vivid::CAnimation &arAnimation, const std::string &arFileType) { //blob
-            Assimp::Exporter exp;
-            EmbeddedTexture = true;
-
-            aiScene *scene = GenerateAnimationScene(arAnimation);
-            auto blob = exp.ExportToBlob(scene, arFileType,
-                                         aiProcess_JoinIdenticalVertices | aiProcess_FixInfacingNormals | aiProcess_GenSmoothNormals);
-
-            EmbeddedTextures.clear();
-            EmbeddedTexture = false;
-            TextureNameToIndex.clear();
-            delete scene;
-
-            if (!blob) {
-                Log(LOG_ERROR, exp.GetErrorString());
-            }
-
-            return CBlobData::FormatExportDataBlob(blob);
-        }
-
-        void AssimpExporter(CModel &arModel, const std::string &arFileType, std::string aOutputPath) {
-            Assimp::Exporter exp;
-            OutputPath = aOutputPath;
-            aiScene *scene = GenerateScene(arModel);
-
-            //clean aOutputPath
-            //if(aOutputPath.find('.')) aOutputPath = aOutputPath.substr(0, aOutputPath.find('.'));
-            aOutputPath += fileFormats[arFileType];
-            auto ret = exp.Export(scene, arFileType, aOutputPath,
-                                  aiProcess_JoinIdenticalVertices | aiProcess_FixInfacingNormals | aiProcess_GenSmoothNormals);
-
-            TextureNameToIndex.clear();
-            OutputPath = "";
-            delete scene;
-
-            if (ret != aiReturn_SUCCESS) {
-                Log(LOG_ERROR, exp.GetErrorString());
-            }
-        }
-
-        void AnimationExporter(CAnimation &arAnimation, const std::string &arFileType, std::string aOutputPath) {
-            Assimp::Exporter exp;
-            OutputPath = aOutputPath;
-            aiScene *scene = GenerateAnimationScene(arAnimation);
-
-            //if(aOutputPath.find('.')) aOutputPath = aOutputPath.substr(0, aOutputPath.find('.'));
-            aOutputPath += fileFormats[arFileType];
-            auto ret = exp.Export(scene, arFileType, aOutputPath);
-            
-            TextureNameToIndex.clear();
-            OutputPath = "";
-            delete scene;
-            
-            if (ret != aiReturn_SUCCESS) {
-                Log(LOG_ERROR, exp.GetErrorString());
-            }
-        }
-
-        aiScene *GenerateScene(const vivid::CModel &model) {
-            //setup scene
-            aiScene *scene = new aiScene();
-            scene->mFlags = AI_SCENE_FLAGS_ALLOW_SHARED;
-            scene->mRootNode = new aiNode();
-            scene->mRootNode->mName = aiString("root_node");
-
-            scene->mNumMeshes = model.GetNumMeshes();
-            scene->mMeshes = new aiMesh *[scene->mNumMeshes];
-
-            scene->mMaterials = new aiMaterial *[scene->mNumMeshes];
-            scene->mNumMaterials = scene->mNumMeshes;
-
-            scene->mRootNode->mNumChildren = 1;
-            scene->mRootNode->mChildren = new aiNode *[1];
-            scene->mRootNode->mChildren[0] = GenerateNode("basic_node", 0, scene->mNumMeshes);
-            scene->mRootNode->mChildren[0]->mParent = scene->mRootNode;
-
-
-            vector<vivid::CModelComponent> meshes = model.GetMeshes();
-
-            string texture_path;
-            for (int i = 0; i < scene->mNumMeshes; i++) {
-                //handle mesh texture
-                texture_path = AddTexture(meshes[i].GetColorMap());
-                //setting up the mesh structure
-                scene->mMeshes[i] = GenerateMesh(&meshes[i]);
-                scene->mMaterials[i] = GenerateMaterial(meshes[i].GetMaterial(), texture_path, i);
-                scene->mMeshes[i]->mMaterialIndex = i;
-            }
-            if(EmbeddedTexture){
-                scene->mNumTextures = EmbeddedTextures.size();
-                scene->mTextures = new aiTexture * [EmbeddedTextures.size()];
-                for(int i = 0; i != EmbeddedTextures.size(); i++){scene->mTextures[i] = EmbeddedTextures[i];}
-            }
-            return scene;
-        }
-
-        aiScene *GenerateAnimationScene(CAnimation &arAnimation) {
-            //setup scene
-            aiScene *scene = new aiScene();
-            scene->mFlags = AI_SCENE_FLAGS_ALLOW_SHARED;
-            scene->mRootNode = new aiNode();
-            scene->mRootNode->mName = aiString("root_node");
-
-            vector<vivid::CModel> models = arAnimation.GetModels();
-
-            scene->mNumMeshes = arAnimation.GetNumMeshes();
-            scene->mMeshes = new aiMesh *[scene->mNumMeshes];
-
-            scene->mMaterials = new aiMaterial *[scene->mNumMeshes];
-            scene->mNumMaterials = scene->mNumMeshes;
-
-            scene->mRootNode->mNumChildren = 1;
-            scene->mRootNode->mChildren = new aiNode *[1];
-            aiNode *center_node = GenerateNode("center_node", 0, 0);
-            scene->mRootNode->mChildren[0] = center_node;
-            scene->mRootNode->mChildren[0]->mParent = scene->mRootNode;
-            center_node->mNumChildren = models.size();
-            center_node->mChildren = new aiNode *[models.size()];
-
-            scene->mNumAnimations = 1;//models.size();
-            scene->mAnimations = new aiAnimation *[1]; //models.size()
-
-
-            CStopMotionAnimation *SMAnimation = dynamic_cast<CStopMotionAnimation *>(&arAnimation);
-            if (!SMAnimation) {
-                scene->mAnimations[0] = GenerateAnimation(arAnimation);
-            } else {
-                scene->mAnimations[0] = GenerateStopMotionAnimation(*SMAnimation);
-            }
-
-            vector<vivid::CModelComponent> meshes;
-            string texture_path;
-            size_t mesh_counter = 0;
-            for (int model_index = 0; model_index != models.size(); model_index++) {
-                meshes = models[model_index].GetMeshes();
-                center_node->mChildren[model_index] = GenerateNode("anim_node_" + to_string(model_index), mesh_counter,
-                                                                   mesh_counter + meshes.size());
-                center_node->mChildren[model_index]->mParent = center_node;
-                for (int mesh_index = 0; mesh_index < meshes.size(); mesh_index++) {
-                    //handle mesh texture
-                    texture_path = AddTexture(meshes[mesh_index].GetColorMap());
-                    //setting up the mesh structure
-                    scene->mMeshes[mesh_counter] = GenerateMesh(&meshes[mesh_index]);
-                    scene->mMaterials[mesh_counter] = GenerateMaterial(meshes[mesh_index].GetMaterial(), texture_path, mesh_counter);
-                    scene->mMeshes[mesh_counter]->mMaterialIndex = mesh_counter;
-                    mesh_counter++;
-                }
-            }
-            if(EmbeddedTexture){
-                scene->mNumTextures = EmbeddedTextures.size();
-                scene->mTextures = new aiTexture * [EmbeddedTextures.size()];
-                for(int i = 0; i != EmbeddedTextures.size(); i++){scene->mTextures[i] = EmbeddedTextures[i];}
-            }
-            return scene;
-        }
-
-        aiAnimation *GenerateAnimation(CAnimation &arAnimation) {
-            aiAnimation *anim = new aiAnimation;
-            anim->mNumChannels = arAnimation.GetModels().size();
-            anim->mChannels = new aiNodeAnim *[anim->mNumChannels];
-            anim->mDuration = arAnimation.GetDuration();
-            anim->mTicksPerSecond = arAnimation.GetTicksPerSecond();
-            anim->mName = aiString("animation");
-            for (int i = 0; i != anim->mNumChannels; i++) {
-                anim->mChannels[i] = GenerateAnimationChannel(arAnimation, i);
-            }
-            return anim;
-        }
-
-        aiAnimation *GenerateStopMotionAnimation(CStopMotionAnimation &arSMAnimation) {
-            aiAnimation *anim = new aiAnimation;
-            anim->mNumChannels = arSMAnimation.GetModels().size();
-            anim->mChannels = new aiNodeAnim *[anim->mNumChannels];
-            int ticks_per_frame = int(arSMAnimation.GetTicksPerSecond() * arSMAnimation.GetSecondsPerFrame());
-            anim->mDuration = anim->mNumChannels * ticks_per_frame;
-            anim->mTicksPerSecond = arSMAnimation.GetTicksPerSecond();
-            anim->mName = aiString("animation");
-            for (int i = 0; i != anim->mNumChannels; i++) {
-                anim->mChannels[i] = new aiNodeAnim;
-                anim->mChannels[i]->mNodeName = aiString("anim_node_" + to_string(i));
-//            anim->mChannels[i]->mPreState = aiAnimBehaviour_CONSTANT;
-//            anim->mChannels[i]->mPostState = aiAnimBehaviour_CONSTANT;
-                //Move
-                CPoint animation_value = arSMAnimation.GetMoveAnim(i);
-                MoveAnimation(anim->mChannels[i], (i + 1) * ticks_per_frame, &animation_value, i * ticks_per_frame);
-                //Rotate
-                animation_value = arSMAnimation.GetRotateAnim(i);
-                RotateAnimation(anim->mChannels[i], (i + 1) * ticks_per_frame, &animation_value, i * ticks_per_frame);
-                //Scale
-                animation_value = arSMAnimation.GetScaleAnim(i);
-                StopMotionScaleAnimation(anim->mChannels[i], (i + 1) * ticks_per_frame, &animation_value,
-                                         i * ticks_per_frame);
-            }
-            return anim;
-        }
-
-        void StopMotionScaleAnimation(aiNodeAnim *arAnim, coord_t aDuration, CPoint *arAnimValue, coord_t aStartTime) {
+        void StopMotionScaleAnimation(aiNodeAnim *arAnim, coord_t aDuration, CPoint *arAnimValue, coord_t aStartTime = 0) {
             if (*arAnimValue != CPoint()) {
                 if (aStartTime == 0) { //make the frame pop out and in when needed
                     arAnim->mNumScalingKeys = int(aDuration - aStartTime) + 3;
@@ -294,7 +81,7 @@ namespace vivid {
         }
 
 
-        void ScaleAnimation(aiNodeAnim *arAnim, coord_t aDuration, CPoint *arAnimValue, coord_t aStartTime) {
+        void ScaleAnimation(aiNodeAnim *arAnim, coord_t aDuration, CPoint *arAnimValue, coord_t aStartTime = 0) {
             if (*arAnimValue != CPoint()) {
                 arAnim->mNumScalingKeys = int(aDuration - aStartTime);
                 arAnim->mScalingKeys = new aiVectorKey[int(aDuration - aStartTime)];
@@ -312,7 +99,7 @@ namespace vivid {
             }
         }
 
-        void MoveAnimation(aiNodeAnim *arAnim, coord_t aDuration, CPoint *arAnimValue, coord_t aStartTime) {
+        void MoveAnimation(aiNodeAnim *arAnim, coord_t aDuration, CPoint *arAnimValue, coord_t aStartTime = 0) {
             if (*arAnimValue != CPoint()) {
                 arAnim->mNumPositionKeys = int(aDuration - aStartTime);
                 arAnim->mPositionKeys = new aiVectorKey[int(aDuration - aStartTime)];
@@ -329,7 +116,7 @@ namespace vivid {
             }
         }
 
-        void RotateAnimation(aiNodeAnim *arAnim, coord_t aDuration, CPoint *arAnimValue, coord_t aStartTime) {
+        void RotateAnimation(aiNodeAnim *arAnim, coord_t aDuration, CPoint *arAnimValue, coord_t aStartTime = 0) {
             if (*arAnimValue != CPoint()) {
                 arAnim->mNumRotationKeys = int(aDuration - aStartTime);
                 arAnim->mRotationKeys = new aiQuatKey[int(aDuration - aStartTime)];
@@ -347,23 +134,23 @@ namespace vivid {
         }
 
         aiNodeAnim *GenerateAnimationChannel(CAnimation &arAnimation, size_t aIndex) {
-            aiNodeAnim *anim_channel = new aiNodeAnim;
+            auto *anim_channel = new aiNodeAnim;
             anim_channel->mNodeName = aiString("anim_node_" + to_string(aIndex));
             //Move
-            CPoint &animation_value = arAnimation.GetMoveAnim(aIndex);
+            CPoint &animation_value = arAnimation.GetFrames()[aIndex].mMoveAnimation;
             MoveAnimation(anim_channel, arAnimation.GetDuration(), &animation_value);
             //Rotate
-            animation_value = arAnimation.GetRotateAnim(aIndex);
+            animation_value = arAnimation.GetFrames()[aIndex].mRotateAnimation;
             RotateAnimation(anim_channel, arAnimation.GetDuration(), &animation_value);
             //Scale
-            animation_value = arAnimation.GetScaleAnim(aIndex);
+            animation_value = arAnimation.GetFrames()[aIndex].mScaleAnimation;
             ScaleAnimation(anim_channel, arAnimation.GetDuration(), &animation_value);
 
             return anim_channel;
         }
 
-        aiNode *GenerateNode(string aNodeName, size_t aMeshIndexStart, size_t aMeshIndexEnd) {
-            aiNode *node = new aiNode();
+        aiNode *GenerateNode(const string& aNodeName, size_t aMeshIndexStart, size_t aMeshIndexEnd) {
+            auto *node = new aiNode();
             node->mName = aiString(aNodeName);
             node->mNumMeshes = aMeshIndexEnd - aMeshIndexStart;
             node->mMeshes = new unsigned int[node->mNumMeshes];
@@ -374,8 +161,29 @@ namespace vivid {
             return node;
         }
 
+        string GenerateTexturePNG(CColorMap &arMeshTexture, std::string &arOutputPath) {
+            string textureName = arOutputPath +"_"+ arMeshTexture.GetName() + "_texture.png";
+            vector<unsigned char> ClmBuffer = arMeshTexture.GetColorTexture();
+            vivid::encodePNG(textureName, ClmBuffer, 1,
+                             ClmBuffer.size() / 4);
+            return textureName.substr(
+                    textureName.find_last_of("/\\") + 1); // remove the path component from the texture name
+        }
+
+        aiTexture *GenerateTextureEmbedded(CColorMap &arMeshTexture) {
+            auto *embedded_texture = new aiTexture();
+            vector<unsigned char> ClmBuffer = arMeshTexture.GetColorTexture();
+            const CMemoryBuffer pngBuffer = encodePNG(ClmBuffer, 1, ClmBuffer.size() / 4); // This is a work of art.
+            strcpy(embedded_texture->achFormatHint, "png");
+            embedded_texture->pcData = (aiTexel*)pngBuffer.mBuffer; // This is bullshit.
+            embedded_texture->mWidth = pngBuffer.mSize;
+            embedded_texture->mHeight = 0; // Assimp expects compressed embedded textures to be with this format.
+            return embedded_texture;
+        }
+
         string AddTexture(CColorMap arMeshCLM) {
             string texture_path;
+            if(arMeshCLM.GetColorMap().size() == 1) return "";
             if (TextureNameToIndex.find(arMeshCLM.GetName()) !=
                 TextureNameToIndex.end()) { //check if texture has been written already
                 texture_path = TextureNameToIndex[arMeshCLM.GetName()];
@@ -390,30 +198,10 @@ namespace vivid {
             }
             return texture_path;
         }
-        
-        string GenerateTexturePNG(CColorMap &arMeshTexture, std::string &arOutputPath) {
-            string textureName = arOutputPath + arMeshTexture.GetName() + "_texture.png";
-            vector<unsigned char> ClmBuffer = arMeshTexture.GetColorTexture();
-            vivid::encodePNG(textureName, ClmBuffer, 1,
-                             ClmBuffer.size() / 4);
-            return textureName.substr(
-                    textureName.find_last_of("/\\") + 1); // remove the path component from the texture name
-        }
-
-        aiTexture *GenerateTextureEmbedded(CColorMap &arMeshTexture) {
-            aiTexture *embedded_texture = new aiTexture();
-            vector<unsigned char> ClmBuffer = arMeshTexture.GetColorTexture();
-            const CMemoryBuffer pngBuffer = encodePNG(ClmBuffer, 1, ClmBuffer.size() / 4); // This is a work of art.
-            strcpy(embedded_texture->achFormatHint, "png");
-            embedded_texture->pcData = (aiTexel*)pngBuffer.mBuffer; // This is bullshit.
-            embedded_texture->mWidth = pngBuffer.mSize;
-            embedded_texture->mHeight = 0; // Assimp expects compressed embedded textures to be with this format.
-            return embedded_texture;
-        }
 
         aiMesh *GenerateMesh(CModelComponent * apMesh) {
             //setting up the apMesh structure
-            aiMesh *OutMesh = new aiMesh();
+            auto *OutMesh = new aiMesh();
             OutMesh->mName = apMesh->GetLabel();
             switch (apMesh->GetObjType()){
                 case TRIANGLES:
@@ -441,11 +229,14 @@ namespace vivid {
 
             /*
                 color flow in vivid works by face. in most 3d formats (and assimp) texture cords are by vertices
-                in this segments we get the average color of each vertice.
+                in this segment we get the average color of each vertice.
             */
-            OutMesh->mTextureCoords[0] = new aiVector3D [vVertices.size()];
-            OutMesh->mNumUVComponents[0] = 2;
-            //OutMesh->mTextureCoords[0][it - vTriangles.begin()] = aiVector3D(0, it->GetQuan(), 0);
+            //if clm is one color dont write UVs
+            bool clm_is_texture = apMesh->GetColorMap().GetColorMap().size() > 1;
+            if(clm_is_texture) {
+                OutMesh->mTextureCoords[0] = new aiVector3D[vVertices.size()];
+                OutMesh->mNumUVComponents[0] = 2;
+            }
 
 
             //assign faces and find average UVcoord per point
@@ -457,7 +248,7 @@ namespace vivid {
                 face.mIndices = new unsigned int[indexes.size()];
                 for (int i = 0; i < indexes.size(); i++) {
                     face.mIndices[i] = indexes[i];
-                    vetUVcoord[indexes[i]].insert(it->GetUVcoord());
+                    if(clm_is_texture) vetUVcoord[indexes[i]].insert(it->GetUVcoord()); //dont write uv cords if the clm is only one color
                 }
             }
 
@@ -465,10 +256,11 @@ namespace vivid {
             double tempAvr, val;
             for (int j = 0; j < vVertices.size(); j++) {
                 OutMesh->mVertices[j] = aiVector3D(vVertices[j].X(), vVertices[j].Y(), vVertices[j].Z());
+                if(!clm_is_texture) continue; //dont write uv cords if the clm is only one color
                 if (!vetUVcoord[j].empty()) { //uv coords
                     tempAvr = 0;
-                    for (auto it = vetUVcoord[j].begin(); it != vetUVcoord[j].end(); ++it) {
-                        tempAvr += *it;
+                    for (auto it : vetUVcoord[j]) {
+                        tempAvr += it;
                     }
                     val = max(0.01, min(1 - tempAvr / vetUVcoord[j].size(), 1.0));
                     OutMesh->mTextureCoords[0][j] = aiVector3D(0, val, 0);
@@ -479,71 +271,320 @@ namespace vivid {
             return OutMesh;
         }
 
-        aiMaterial *GenerateMaterial(const vivid::CMaterial& arMaterial, const string& aTextureName, size_t mat_index) {
-            aiMaterial *material = new aiMaterial();
-
+        aiMaterial *GenerateMaterial(const vivid::CModelComponent& arMesh, const string& aTextureName, size_t mat_index) {
+            const auto arMaterial = arMesh.GetMaterial();
+            auto cmap = arMesh.GetColorMap().GetColorMap();
+            auto *material = new aiMaterial();
+            // name
             const aiString *name = new aiString(arMaterial.GetLabel() + "_mat"+ to_string(mat_index));
             material->AddProperty(name, AI_MATKEY_NAME);
 
-            const array<float, 3> mat_emissive_color = ToNormalRGB(COLORS.at(arMaterial.GetEmissionColor()));
-            const aiColor3D *emissive_color = new aiColor3D(mat_emissive_color[0], mat_emissive_color[1], mat_emissive_color[2]);
+            // base color
+            aiColor4D *diffuse_color;
+            if (cmap.size() == 1) {
+                const auto base_color = ToNormalRGB(cmap[0]);
+                diffuse_color = new aiColor4D(base_color[0], base_color[1], base_color[2], 1);
+            } else {
+                diffuse_color = new aiColor4D(1, 1, 1, 1);
+            }
+            material->AddProperty(diffuse_color, 4, AI_MATKEY_COLOR_DIFFUSE);
+
+            //const aiColor3D *ambient_color = new aiColor3D(1, 1, 1);
+            material->AddProperty(diffuse_color, 4, AI_MATKEY_COLOR_AMBIENT);
+            // emissive color
+            const auto emission_factor = arMaterial.GetEmissionStrength();
+            const auto emission_color = min(emission_factor, 1.0f);
+            aiColor3D *emissive_color;
+            if (cmap.size() == 1) {
+                const auto base_color = ToNormalRGB(cmap[0]);
+                emissive_color = new aiColor3D(base_color[0] * emission_color, base_color[1] * emission_color, base_color[2] * emission_color);
+            } else {
+                emissive_color = new aiColor3D(emission_color, emission_color, emission_color);
+            }
             material->AddProperty(emissive_color, 3,AI_MATKEY_COLOR_EMISSIVE);
-        
+
+            // emissive strength
+            const float *emissive_intensity = new float(max(emission_factor, 1.0f));
+            material->AddProperty(emissive_intensity, 1, AI_MATKEY_EMISSIVE_INTENSITY);
+
+            // metalness
+            const float *metalness = new float(arMaterial.GetMetalness());
+            material->AddProperty(metalness, 1, AI_MATKEY_METALLIC_FACTOR);
+
+            // roughness
+            const float *roughness = new float(arMaterial.GetRoughness());
+            material->AddProperty(roughness, 1, AI_MATKEY_ROUGHNESS_FACTOR);
+
+            // opacity
+            const float *opacity = new float(arMaterial.GetOpacity());
+            material->AddProperty(opacity, 1, AI_MATKEY_OPACITY);
+
+            // textures
+            if(cmap.size() > 1) { //one color
+                const int *uvwsrc = new int(0);
+                material->AddProperty(uvwsrc, 1, AI_MATKEY_UVWSRC_AMBIENT(0));
+
+                material->AddProperty(uvwsrc, 1, AI_MATKEY_UVWSRC_DIFFUSE(0));
+
+                material->AddProperty(uvwsrc, 1, AI_MATKEY_UVWSRC_EMISSIVE(0));
+
+                const aiString *texIndex = new aiString(aTextureName.substr(aTextureName.find_last_of("/\\") + 1));
+                material->AddProperty(texIndex, AI_MATKEY_TEXTURE_DIFFUSE(0));
+
+                material->AddProperty(texIndex, AI_MATKEY_TEXTURE_AMBIENT(0));
+
+                material->AddProperty(texIndex, AI_MATKEY_TEXTURE_EMISSIVE(0));
+            }
+            // twosided
+            const int *twosided = new int(1);
+            material->AddProperty(twosided, 1, AI_MATKEY_TWOSIDED);
+
+            // obj specific things
             const int *shading_model = new int(2);
             material->AddProperty(shading_model, 1, AI_MATKEY_SHADING_MODEL);
 
             const int *illum = new int(0);
             material->AddProperty(illum, 1, "$mat.illum", 4, 0);  // going around assimp system
 
-            const aiColor4D *diffuse_color = new aiColor4D(1, 1, 1, 1);
-            material->AddProperty(diffuse_color, 3, AI_MATKEY_COLOR_DIFFUSE);
-
-            const aiColor3D *ambient_color = new aiColor3D(1, 1, 1);
-            material->AddProperty(ambient_color, 3, AI_MATKEY_COLOR_AMBIENT);
+            // TODO: Are the rest of these needed?
 
             const aiColor3D *specular_color = new aiColor3D(0, 0, 0);
             material->AddProperty(specular_color, 3, AI_MATKEY_COLOR_SPECULAR);
 
-
-            const aiColor3D *color_transparent = new aiColor3D(1, 1, 1);
-            material->AddProperty(color_transparent, 3, AI_MATKEY_COLOR_TRANSPARENT);
-
-            
-            const float *shininess = new float(arMaterial.GetShininess() * MAX_ROUGHNESS);
-            material->AddProperty(shininess, 1, AI_MATKEY_SHININESS);
-
-            const float *opacity = new float(arMaterial.GetOpacity());
-            material->AddProperty(opacity, 1, AI_MATKEY_OPACITY);
+//            const aiColor3D *color_transparent = new aiColor3D(1, 1, 1);
+//            material->AddProperty(color_transparent, 3, AI_MATKEY_COLOR_TRANSPARENT);
 
             const float *anisotrpy_factor = new float(0);
             material->AddProperty(anisotrpy_factor, 1, AI_MATKEY_ANISOTROPY_FACTOR);
-            
-            const float *emissive_intensity = new float(arMaterial.GetEmissionStrength());
-            material->AddProperty(emissive_intensity, 1, AI_MATKEY_EMISSIVE_INTENSITY);
 
             const float *refracti = new float(1);
             material->AddProperty(refracti, 1, AI_MATKEY_REFRACTI);
 
-            const int *twosided = new int(!0);
-            material->AddProperty(twosided, 1, AI_MATKEY_TWOSIDED);
-            //texture property
-
-            const int *uvwsrc = new int(0);
-            material->AddProperty(uvwsrc, 1, AI_MATKEY_UVWSRC_AMBIENT(0));
-
-            material->AddProperty(uvwsrc, 1, AI_MATKEY_UVWSRC_DIFFUSE(0));
-
-            material->AddProperty(uvwsrc, 1, AI_MATKEY_UVWSRC_EMISSIVE(0));
-
-            const aiString *texIndex = new aiString(aTextureName.substr(aTextureName.find_last_of("/\\") + 1));
-            material->AddProperty(texIndex, AI_MATKEY_TEXTURE_DIFFUSE(0));
-
-            material->AddProperty(texIndex, AI_MATKEY_TEXTURE_AMBIENT(0));
-
-            material->AddProperty(texIndex, AI_MATKEY_TEXTURE_EMISSIVE(0));
-
             return material;
         }
+
+
+
+        aiScene *GenerateScene(vivid::CModel &model) {
+            //setup scene
+            auto *scene = new aiScene();
+            scene->mFlags = AI_SCENE_FLAGS_ALLOW_SHARED;
+            scene->mRootNode = new aiNode();
+            scene->mRootNode->mName = aiString("root_node");
+
+            scene->mNumMeshes = model.GetNumMeshes();
+            scene->mMeshes = new aiMesh *[scene->mNumMeshes];
+
+            scene->mMaterials = new aiMaterial *[scene->mNumMeshes];
+            scene->mNumMaterials = scene->mNumMeshes;
+
+            scene->mRootNode->mNumChildren = 1;
+            scene->mRootNode->mChildren = new aiNode *[1];
+            scene->mRootNode->mChildren[0] = GenerateNode("basic_node", 0, scene->mNumMeshes);
+            scene->mRootNode->mChildren[0]->mParent = scene->mRootNode;
+
+
+            vector<vivid::CModelComponent> meshes = model.GetMeshes();
+
+            string texture_path;
+            for (int i = 0; i < scene->mNumMeshes; i++) {
+                //handle mesh texture
+                texture_path = AddTexture(meshes[i].GetColorMap());
+                //setting up the mesh structure
+                scene->mMeshes[i] = GenerateMesh(&meshes[i]);
+                scene->mMaterials[i] = GenerateMaterial(meshes[i], texture_path, i);
+                scene->mMeshes[i]->mMaterialIndex = i;
+            }
+            if(EmbeddedTexture){
+                scene->mNumTextures = EmbeddedTextures.size();
+                scene->mTextures = new aiTexture * [EmbeddedTextures.size()];
+                for(int i = 0; i != EmbeddedTextures.size(); i++){scene->mTextures[i] = EmbeddedTextures[i];}
+            }
+            return scene;
+        }
+
+        aiAnimation *GenerateAnimation(CAnimation &arAnimation) {
+            auto *anim = new aiAnimation;
+            anim->mNumChannels = arAnimation.GetNumModels();
+            anim->mChannels = new aiNodeAnim *[anim->mNumChannels];
+            anim->mDuration = arAnimation.GetDuration();
+            anim->mTicksPerSecond = arAnimation.GetTicksPerSecond();
+            anim->mName = aiString("animation");
+            for (int i = 0; i != anim->mNumChannels; i++) {
+                anim->mChannels[i] = GenerateAnimationChannel(arAnimation, i);
+            }
+            return anim;
+        }
+
+        aiAnimation *GenerateStopMotionAnimation(CStopMotionAnimation &arSMAnimation) {
+            auto *anim = new aiAnimation;
+            anim->mNumChannels = arSMAnimation.GetNumModels();
+            anim->mChannels = new aiNodeAnim *[anim->mNumChannels];
+            int ticks_per_frame = int(arSMAnimation.GetTicksPerSecond() * arSMAnimation.GetSecondsPerFrame());
+            anim->mDuration = anim->mNumChannels * ticks_per_frame;
+            anim->mTicksPerSecond = arSMAnimation.GetTicksPerSecond();
+            anim->mName = aiString("animation");
+            for (int i = 0; i != anim->mNumChannels; i++) {
+                anim->mChannels[i] = new aiNodeAnim;
+                anim->mChannels[i]->mNodeName = aiString("anim_node_" + to_string(i));
+//            anim->mChannels[i]->mPreState = aiAnimBehaviour_CONSTANT;
+//            anim->mChannels[i]->mPostState = aiAnimBehaviour_CONSTANT;
+                //Move
+                CPoint animation_value = arSMAnimation.GetFrames()[i].mMoveAnimation;
+                MoveAnimation(anim->mChannels[i], (i + 1) * ticks_per_frame, &animation_value, i * ticks_per_frame);
+                //Rotate
+                animation_value = arSMAnimation.GetFrames()[i].mRotateAnimation;
+                RotateAnimation(anim->mChannels[i], (i + 1) * ticks_per_frame, &animation_value, i * ticks_per_frame);
+                //Scale
+                animation_value = arSMAnimation.GetFrames()[i].mScaleAnimation;
+                StopMotionScaleAnimation(anim->mChannels[i], (i + 1) * ticks_per_frame, &animation_value,
+                                         i * ticks_per_frame);
+            }
+            return anim;
+        }
+
+
+        aiScene *GenerateAnimationScene(CAnimation &arAnimation) {
+            //setup scene
+            auto *scene = new aiScene();
+            scene->mFlags = AI_SCENE_FLAGS_ALLOW_SHARED;
+            scene->mRootNode = new aiNode();
+            scene->mRootNode->mName = aiString("root_node");
+
+            vector<vivid::CFrame> models = arAnimation.GetFrames();
+
+            scene->mNumMeshes = arAnimation.GetNumMeshes();
+            scene->mMeshes = new aiMesh *[scene->mNumMeshes];
+
+            scene->mMaterials = new aiMaterial *[scene->mNumMeshes];
+            scene->mNumMaterials = scene->mNumMeshes;
+
+            scene->mRootNode->mNumChildren = 1;
+            scene->mRootNode->mChildren = new aiNode *[1];
+            aiNode *center_node = GenerateNode("center_node", 0, 0);
+            scene->mRootNode->mChildren[0] = center_node;
+            scene->mRootNode->mChildren[0]->mParent = scene->mRootNode;
+            center_node->mNumChildren = models.size();
+            center_node->mChildren = new aiNode *[models.size()];
+
+            scene->mNumAnimations = 1;//models.size();
+            scene->mAnimations = new aiAnimation *[1]; //models.size()
+
+
+            auto *SMAnimation = dynamic_cast<CStopMotionAnimation *>(&arAnimation);
+            if (!SMAnimation) {
+                scene->mAnimations[0] = GenerateAnimation(arAnimation);
+            } else {
+                scene->mAnimations[0] = GenerateStopMotionAnimation(*SMAnimation);
+            }
+
+            vector<vivid::CModelComponent> meshes;
+            string texture_path;
+            size_t mesh_counter = 0;
+            for (int model_index = 0; model_index != models.size(); model_index++) {
+                meshes = models[model_index].mModel.GetMeshes();
+                center_node->mChildren[model_index] = GenerateNode("anim_node_" + to_string(model_index), mesh_counter,
+                                                                   mesh_counter + meshes.size());
+                center_node->mChildren[model_index]->mParent = center_node;
+                for (auto & mesh : meshes) {
+                    //handle mesh texture
+                    texture_path = AddTexture(mesh.GetColorMap());
+                    //setting up the mesh structure
+                    scene->mMeshes[mesh_counter] = GenerateMesh(&mesh);
+                    scene->mMaterials[mesh_counter] = GenerateMaterial(mesh, texture_path, mesh_counter);
+                    scene->mMeshes[mesh_counter]->mMaterialIndex = mesh_counter;
+                    mesh_counter++;
+                }
+            }
+            if(EmbeddedTexture){
+                scene->mNumTextures = EmbeddedTextures.size();
+                scene->mTextures = new aiTexture * [EmbeddedTextures.size()];
+                for(int i = 0; i != EmbeddedTextures.size(); i++){scene->mTextures[i] = EmbeddedTextures[i];}
+            }
+            return scene;
+        }
+
+    }
+
+    namespace AssimpExport {
+
+        CBlobData AssimpExporter(vivid::CModel &arModel, const std::string &arFileType) {
+            Assimp::Exporter exp;
+            EmbeddedTexture = true;
+
+            aiScene *scene = GenerateScene(arModel);
+            auto blob = exp.ExportToBlob(scene, RenameGLTF_GLB(arFileType),
+                                   aiProcess_JoinIdenticalVertices | aiProcess_FixInfacingNormals | aiProcess_GenSmoothNormals);
+
+            EmbeddedTextures.clear();
+            EmbeddedTexture = false;
+            TextureNameToIndex.clear();
+            delete scene;
+            
+            if (!blob) {
+                Log(LOG_ERROR, exp.GetErrorString());
+            }
+            // we copy all the blob data to a vivid const qualified struct so the blob pointer isn't freed by python's greedy GC
+            return CBlobData::FormatExportDataBlob(blob);
+        }
+
+        CBlobData AnimationExporter(vivid::CAnimation &arAnimation, const std::string &arFileType) {
+            Assimp::Exporter exp;
+            EmbeddedTexture = true;
+
+            aiScene *scene = GenerateAnimationScene(arAnimation);
+            auto blob = exp.ExportToBlob(scene, RenameGLTF_GLB(arFileType),
+                                         aiProcess_JoinIdenticalVertices | aiProcess_FixInfacingNormals | aiProcess_GenSmoothNormals);
+
+            EmbeddedTextures.clear();
+            EmbeddedTexture = false;
+            TextureNameToIndex.clear();
+            delete scene;
+
+            if (!blob) {
+                Log(LOG_ERROR, exp.GetErrorString());
+            }
+
+            return CBlobData::FormatExportDataBlob(blob);
+        }
+
+        void AssimpExporter(CModel &arModel, const std::string &arFileType, std::string aOutputPath) {
+            Assimp::Exporter exp;
+            OutputPath = aOutputPath;
+            aiScene *scene = GenerateScene(arModel);
+
+            //clean aOutputPath
+            //if(aOutputPath.find('.')) aOutputPath = aOutputPath.substr(0, aOutputPath.find('.'));
+            aOutputPath += FILE_FORMATS.at(arFileType);
+            auto ret = exp.Export(scene, RenameGLTF_GLB(arFileType), aOutputPath,
+                                  aiProcess_JoinIdenticalVertices | aiProcess_FixInfacingNormals | aiProcess_GenSmoothNormals);
+
+            TextureNameToIndex.clear();
+            OutputPath = "";
+            delete scene;
+
+            if (ret != aiReturn_SUCCESS) {
+                Log(LOG_ERROR, exp.GetErrorString());
+            }
+        }
+
+        void AnimationExporter(CAnimation &arAnimation, const std::string &arFileType, std::string aOutputPath) {
+            Assimp::Exporter exp;
+            OutputPath = aOutputPath;
+            aiScene *scene = GenerateAnimationScene(arAnimation);
+
+            //if(aOutputPath.find('.')) aOutputPath = aOutputPath.substr(0, aOutputPath.find('.'));
+            aOutputPath += FILE_FORMATS.at(arFileType);
+            auto ret = exp.Export(scene, RenameGLTF_GLB(arFileType), aOutputPath);
+            
+            TextureNameToIndex.clear();
+            OutputPath = "";
+            delete scene;
+            
+            if (ret != aiReturn_SUCCESS) {
+                Log(LOG_ERROR, exp.GetErrorString());
+            }
+        }
     }
 }
 /*  assymp material components
