@@ -1,8 +1,5 @@
 #include <numeric>
 #include "Mesh.h"
-#include "Model.h"
-#include "../../lib/Decimate.h"
-#include "../Utils/ProgressBar.h"
 #include "boost/algorithm/string/predicate.hpp"
 using namespace vivid;
 using namespace boost::algorithm;
@@ -13,12 +10,12 @@ void CMesh::Reduce(coord_t aVerticlePercent, coord_t aMaxError)
 {
     //check input valdilty
     if( aVerticlePercent < 0 || aVerticlePercent > 1){
-        aVerticlePercent = max(0.05, min(aVerticlePercent, .9));
-        CLogFile::GetInstance().Write(ELogCode::LOG_ERROR, ELogMessage::INVALID_ALPHA_VALUE);
+        aVerticlePercent = max((coord_t)0.05, min(aVerticlePercent, (coord_t).9));
+        Log(LOG_WARNING, INVALID_ALPHA_VALUE);
     }
     if( aMaxError < 0 || aMaxError > 1){
-        aMaxError = max(0.05, min(aMaxError, .9));
-        CLogFile::GetInstance().Write(ELogCode::LOG_ERROR, ELogMessage::INVALID_ALPHA_VALUE);
+        aMaxError = max((coord_t)0.05, min(aMaxError, (coord_t).9));
+        Log(LOG_WARNING, INVALID_ALPHA_VALUE);
     }
     if (!mFacesAreTriangles) { TriangulizeFaces(); }
     //call decimation from External
@@ -169,18 +166,8 @@ void CMesh::LaplacianSmooth(size_t aNumIterations, double aAlphaFactor, double a
     mPoints = curr_points;
 }
 
-void CMesh::ExportToObj(const std::string &arOutputFilePath, bool aWithTexture){
-    CModel(*this).ExportToObj(arOutputFilePath, aWithTexture);
-}
-
-int CMesh::Export(const std::string &arOutputFilePath, std::string aFileType){
-    return CModel(*this).Export(arOutputFilePath, aFileType);
-}
-
 void CMesh::CalculatePointsNeighbours() {
-    size_t i =0;
     for (auto & mFace : mFaces) {
-        if (i%100==0) { printProgress(i/mFaces.size()); }
 
         size_t n_points = mFace.GetPoints().size();
         for (int j = 0; j < n_points; j++) {
@@ -195,7 +182,6 @@ void CMesh::CalculatePointsNeighbours() {
             mPointNeighbours[mFace[j]].insert(prev);
             mPointNeighbours[mFace[j]].insert(next);
         }
-        i++;
     }
 }
 
@@ -207,67 +193,20 @@ void CMesh::TriangulizeFaces() {
         size_t prev_0=0, prev_1=1, prev_2=2;
         for (size_t i = 1; i < mFace.GetPoints().size()-1; i++) {
             // Add faces along alternating diagonals
-            if (i%2 == 1){
-                triangle_faces.push_back(CFace({mFace[prev_0], mFace[prev_1], mFace[prev_2]}, mFace.GetUVcoord()));
-            } else {
-                prev_1 = mFace.GetPoints().size()-prev_1;
-                triangle_faces.push_back(CFace({mFace[prev_0], mFace[prev_1], mFace[prev_2]}, mFace.GetUVcoord()));
-                if (prev_0 == 0) { prev_0 = 3;}
-                else { prev_0++;}
-                prev_1+=prev_2;
-                prev_2=prev_1-prev_2;
-                prev_1-=prev_2;
-            }
-//            triangle_faces.push_back(CFace({mFace[0], mFace[i], mFace[i + 1]}, mFace.GetUVcoords()));
+//            if (i%2 == 1){
+//                triangle_faces.push_back(CFace({mFace[prev_0], mFace[prev_1], mFace[prev_2]}, mFace.GetUVcoord()));
+//            } else {
+//                prev_1 = mFace.GetPoints().size()-prev_1;
+//                triangle_faces.push_back(CFace({mFace[prev_0], mFace[prev_1], mFace[prev_2]}, mFace.GetUVcoord()));
+//                if (prev_0 == 0) { prev_0 = 3;}
+//                else { prev_0++;}
+//                prev_1+=prev_2;
+//                prev_2=prev_1-prev_2;
+//                prev_1-=prev_2;
+//            }
+            triangle_faces.push_back(CFace({mFace[0], mFace[i], mFace[i + 1]}, mFace.GetUVcoord()));
         }
     }
     mFaces = triangle_faces;
     mFacesAreTriangles = true;
-}
-
-/*--------------------------------------------- Transformation Methods -----------------------------------------------*/
-
-void CMesh::TransformMesh(FTrans_t const &arTrans){
-    for (auto & mPoint : mPoints)
-    {
-        mPoint = arTrans(mPoint);
-    }
-}
-
-void CMesh::TransformMesh(const array<CPoint, 3>& aTrans)
-{
-    for (auto & mPoint : mPoints)
-    {
-        mPoint = {mPoint.Dot(aTrans[0]), mPoint.Dot(aTrans[1]), mPoint.Dot(aTrans[2])};
-    }
-}
-
-void CMesh::RotateMesh(const CPoint& arNormVec, double aRadAngel)
-{
-    auto cos_a = cos(aRadAngel);
-    auto sin_a = sin(aRadAngel);
-    auto one_min_cos_a = 1-cos_a;
-    auto nx = arNormVec.X();
-    auto ny = arNormVec.Y();
-    auto nz = arNormVec.Z();
-
-    array<CPoint, 3> rotation_mat =  {
-            CPoint(cos_a + nx*nx*one_min_cos_a,    nx*ny*one_min_cos_a - nz*sin_a, nx*nz*one_min_cos_a + ny*sin_a),
-            CPoint(ny*nx*one_min_cos_a + nz*sin_a, cos_a + ny*ny*one_min_cos_a,    ny*nz*one_min_cos_a - nx*sin_a),
-            CPoint(nz*nx*one_min_cos_a - ny*sin_a, nz*ny*one_min_cos_a + nx*sin_a, cos_a + nz*nz*one_min_cos_a),
-    };
-    TransformMesh(rotation_mat);
-}
-
-void CMesh::MoveMesh(const CPoint& arDirectionVec){
-    for (auto & mPoint : mPoints)
-    {
-        mPoint += arDirectionVec;
-    }
-}
-
-void CMesh::ScaleMesh(const CPoint& arScaleVec) {
-    for (auto &mPoint: mPoints) {
-        mPoint.Scale(arScaleVec);
-    }
 }
\ No newline at end of file
