@@ -102,7 +102,7 @@ namespace vivid
         * @param[in] arOutputFilePath Path and name for output file
         * @param[in] aFileType 3D filetype format to write to (out of supported options)
         */
-        void Export(const std::string &arOutputFilePath, const std::string& arFileType = "gltf2");
+        void Export(const std::string &arOutputFilePath, const std::string& arFileType = "glb");
         /**
         * Assimp export. returns arModel in aFileType format
         * @param[in] aFileType 3D filetype format to write to (out of supported options)
